@@ -32,8 +32,7 @@ DIST=$(rpm --eval "%{dist}" | cut -d. -f2)
 DISTNAME=${DIST}
 
 # Special handling of FC rawhide
-[[ "${DISTNAME}" == "fc39" ]] && DISTNAME="fc-rawhide"
-[[ "${DISTNAME}" == "fc40" ]] && DISTNAME="fc-rawhide"
+[[ "${DISTNAME}" == "fc41" ]] && DISTNAME="fc-rawhide"
 
 # Write repository files to /etc/yum.repos.d/ based on the branch name
 REPO_FILE=$(./ci/write-repo-file.sh)
@@ -44,12 +43,6 @@ SRPMS=${RPMBUILD}/SRPMS
 
 cd packaging/
 make srpm RELEASE=${RELEASE} RPMBUILD=${RPMBUILD} SRPMS=${SRPMS}
-
-if [[ -f /usr/bin/dnf ]]; then
-  dnf install -y epel-release || true
-  dnf builddep -y ${SRPMS}/*
-else
-  yum-builddep -y ${SRPMS}/*
-fi
+dnf builddep -y ${SRPMS}/*
 
 rpmbuild --rebuild --define="_topdir ${RPMBUILD}" ${SRPMS}/*
